## Arches for Science 2.0.3 Release Notes


### Bug Fixes and Enhancements

- Return thumbnails for manifest image digital resources [#1608](https://github.com/archesproject/arches-for-science/pull/1608)

### Dependency changes:

```
Python:
    Upgraded:
        None
JavaScript:
    Upgraded:
        None
```

### Breaking Changes
Due to changes in how projects and apps are configured in the final release of Arches 7.6, there are significant project alterations necessary to migrate from Arches for Science 1.1 to Arches for Science 2.0.

### Upgrading Arches for Science 
1. Start by upgrading your project to run using [Arches 7.6](https://github.com/archesproject/arches/blob/dev/7.6.x/releases/7.6.0.md#upgrading-arches). 

2. Update arches-for-science in your project's package.json file:
    ```
    "arches_for_science": "archesproject/arches-for-science#dev/2.0.x"
    ```

3. Add arches_for_science to your project's dependencies in your pyproject.toml file:
    ```
    "arches_for_science>=2.0.3,<2.1.0"
    ```

4. Upgrade to Arches for Science 2.0.3
    ```
    pip install --upgrade arches_for_science==2.0.3
    ```


